OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Visor de ficheiros sinxelo con diaporama para multimedia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Presente as fotos e vídeos das súas vacacións como nos filmes, amose un adianto da súa novela directamente dende a súa nube, escolla as mellores imaxes GIF da súa colección grazas á vista previa dos seus ficheiros favoritos, e moito máis!",
    "Your browser does not support audio." : "O seu navegador non admite son.",
    "Error loading {name}" : "Produciuse un erro ao cargar {name}",
    "Unsaved changes" : "Cambios sen gardar",
    "Your browser does not support videos." : "O seu navegador non admite vídeos",
    "Edit" : "Editar",
    "Open sidebar" : "Abrir a barra lateral",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "There is no plugin available to display this file type" : "Non hai ningún complemento dispoñíbel para amosar este tipo de ficheiro",
    "View" : "Ver",
    "Name" : "Nome",
    "Save" : "Gardar",
    "Back" : "Atrás",
    "Loading …" : "Cargando…",
    "Reset" : "Restabelecer",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Undo" : "Desfacer",
    "Redo" : "Refacer",
    "Zoom in" : "Achegar",
    "Original" : "Orixinal",
    "Custom" : "Personalizado",
    "Value" : "Valor",
    "Image" : "Imaxe",
    "Text" : "Texto",
    "Size" : "Tamaño",
    "Position" : "Posicion",
    "Extension" : "Extensión",
    "Name is required." : "É obrigatorio  o nome.",
    "Quality" : "Calidade"
},
"nplurals=2; plural=(n != 1);");
